==> jc-1.4.0.tar.gz: soot/jimple/ReachingTypeDumper__24StringComparator.h <==
// class soot.jimple.ReachingTypeDumper$StringComparator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class edefe1a352b448c3 soot_jimple_ReachingTypeDumper__24StringComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_ReachingTypeDumper__24StringComparator_H_
#define _JC_soot_jimple_ReachingTypeDumper__24StringComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_ReachingTypeDumper$object;

// Typedefs
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_refs	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_refs;
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_nonrefs	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_nonrefs;
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$refs	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$refs;
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$nonrefs	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$nonrefs;
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$object;

typedef const struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vmethods	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vmethods;
typedef const struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtable	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtable;
typedef const struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype;

// Constructors
extern void _jc_soot_jimple_ReachingTypeDumper__24StringComparator$method$_init$5cc6e1bb542a36df(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object *, struct _jc_soot_jimple_ReachingTypeDumper$object *);

// Virtual methods
extern jint _jc_soot_jimple_ReachingTypeDumper__24StringComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_ReachingTypeDumper__24StringComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vmethods	soot_jimple_ReachingTypeDumper__24StringComparator;
};

// Vtype
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype {
	_jc_type			type;
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_refs {
	struct _jc_soot_jimple_ReachingTypeDumper$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$refs {
    _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_refs	soot_jimple_ReachingTypeDumper__24StringComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_nonrefs	soot_jimple_ReachingTypeDumper__24StringComparator;
};

// Object instance structure
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object {
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype	*vtype;
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype _jc_soot_jimple_ReachingTypeDumper__24StringComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_ReachingTypeDumper__24StringComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_ReachingTypeDumper__24StringComparator$class_object;

#endif	/* _JC_soot_jimple_ReachingTypeDumper__24StringComparator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/ReachingTypeDumper__24StringComparator.h <==
// class soot.jimple.ReachingTypeDumper$StringComparator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class edefe1a352b448c3 soot_jimple_ReachingTypeDumper__24StringComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_ReachingTypeDumper__24StringComparator_H_
#define _JC_soot_jimple_ReachingTypeDumper__24StringComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_ReachingTypeDumper$object;

// Typedefs
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_refs	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_refs;
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_nonrefs	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_nonrefs;
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$refs	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$refs;
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$nonrefs	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$nonrefs;
typedef struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$object;

typedef const struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vmethods	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vmethods;
typedef const struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtable	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtable;
typedef const struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype;

// Constructors
extern void _jc_soot_jimple_ReachingTypeDumper__24StringComparator$method$_init$5cc6e1bb542a36df(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object *, struct _jc_soot_jimple_ReachingTypeDumper$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_jimple_ReachingTypeDumper__24StringComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_ReachingTypeDumper__24StringComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vmethods	soot_jimple_ReachingTypeDumper__24StringComparator;
};

// Vtype
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype {
	_jc_type			type;
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_refs {
	struct _jc_soot_jimple_ReachingTypeDumper$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$refs {
    _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_refs	soot_jimple_ReachingTypeDumper__24StringComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_ReachingTypeDumper__24StringComparator$sub_nonrefs	soot_jimple_ReachingTypeDumper__24StringComparator;
};

// Object instance structure
struct _jc_soot_jimple_ReachingTypeDumper__24StringComparator$object {
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype	*vtype;
	_jc_soot_jimple_ReachingTypeDumper__24StringComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_ReachingTypeDumper__24StringComparator$vtype _jc_soot_jimple_ReachingTypeDumper__24StringComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_ReachingTypeDumper__24StringComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_ReachingTypeDumper__24StringComparator$class_object;

#endif	/* _JC_soot_jimple_ReachingTypeDumper__24StringComparator_H_ */
